<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.5.0-alpha
 * @author     Thomas Griffin
 * @author     Gary Jones
 * @copyright  Copyright (c) 2011, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/thomasgriffin/TGM-Plugin-Activation
 */

/**
 * Include the TGM_Plugin_Activation class.
 */
require_once('class-tgm-plugin-activation.php');

add_action( 'tgmpa_register', 'my_theme_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function my_theme_register_required_plugins() {

	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(

		// how to include a plugin from the WordPress Plugin Repository
		array(
			'name' 		=> 'Mj Testimonial',
			'slug' 		=> 'mj_testimonial',
			'source'             => get_stylesheet_directory() . '/inc/plugins/mj_testimonial.zip', // The plugin source.
			'required' 	=> true,
			'force_activation' 		=> true,
			'force_deactivation' 	=> true,
		),
		array(
			'name' 		=> 'Woocommerce',
			'slug' 		=> 'woocommerce',
			'required' 	=> true,
			'force_activation' 		=> true,
			'force_deactivation' 	=> true,
		),
		array(
			'name' 		=> 'YITH WooCommerce Compare',
			'slug' 		=> 'yith-woocommerce-compare',
			'required' 	=> true,
			'force_activation' 		=> true,
			'force_deactivation' 	=> true,
		),
		array(
			'name' 		=> 'YITH WooCommerce Wishlist',
			'slug' 		=> 'yith-woocommerce-wishlist',
			'required' 	=> true,
			'force_activation' 		=> true,
			'force_deactivation' 	=> true,
		),
		array(
			'name' 		=> 'Revolution Slider',
			'slug' 		=> 'revslider',
			'source'             => get_stylesheet_directory() . '/inc/plugins/revslider.zip',
			'required' 	=> true,
			'force_activation' 		=> true,
			'force_deactivation' 	=> true,
		),
		array(
			'name' 		=> 'bbPress',
			'slug' 		=> 'bbpress',
			'required' 	=> true,
			'force_activation' 		=> true,
			'force_deactivation' 	=> true,
		),
		array(
			'name' 		=> 'Spicy Form',
			'slug' 		=> 'spicy-form',
			'source'             => get_stylesheet_directory() . '/inc/plugins/spicy-form.zip',
			'required' 	=> true,
			'force_activation' 		=> true,
			'force_deactivation' 	=> true,
		),
		array(
			'name' 		=> 'MailChimp for WordPress Lite',
			'slug' 		=> 'mailchimp-for-wp',
			'required' 	=> true,
			'force_activation' 		=> true,
			'force_deactivation' 	=> true,
		),
		array(
			'name' 		=> 'PHP Code Widget',
			'slug' 		=> 'php-code-widget',
			'required' 	=> true,
			'force_activation' 		=> true,
			'force_deactivation' 	=> true,
		),		
		array(
			'name' 		=> 'WPBakery Visual Composer',
			'slug' 		=> 'js_composer',
			'source'             => get_stylesheet_directory() . '/inc/plugins/js_composer.zip',
			'required' 	=> true,
			'force_activation' 		=> false,
			'force_deactivation' 	=> false,
		),
		array(
			'name' 		=> 'WooCommerce Warranty & Return System',
			'slug' 		=> 'woocommerce-warranty-return-system',
			'source'             => get_stylesheet_directory() . '/inc/plugins/woocommerce-warranty-return-system.zip',
			'required' 	=> true,
			'force_activation' 		=> false,
			'force_deactivation' 	=> false,
		),
		array(
			'name' 		=> 'Cart2CRM',
			'slug' 		=> 'Cart2CRM',
			'source'             => get_stylesheet_directory() . '/inc/plugins/Cart2CRM.zip',
			'required' 	=> true,
			'force_activation' 		=> false,
			'force_deactivation' 	=> false,
		),
		array(
			'name' 		=> 'WordPress SEO',
			'slug' 		=> 'wordpress-seo',
			'required' 	=> true,
			'force_activation' 		=> false,
			'force_deactivation' 	=> false,
		),
		
	);

	/*
	 * Array of configuration settings. Amend each line as needed.
	 * If you want the default strings to be available under your own theme domain,
	 * leave the strings uncommented.
	 * Some of the strings are wrapped in a sprintf(), so see the comments at the
	 * end of each line for what each argument will be.
	 */
	$config = array(
		'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to pre-packaged plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'parent_slug'  => 'themes.php',            // Parent menu slug.
		'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
		'strings'      => array(
			'page_title'                      => __( 'Install Required Plugins', 'kybully' ),
			'menu_title'                      => __( 'Install Plugins', 'kybully' ),
			'installing'                      => __( 'Installing Plugin: %s', 'kybully' ), // %s = plugin name.
			'oops'                            => __( 'Something went wrong with the plugin API.', 'kybully' ),
			'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'kybully' ), // %1$s = plugin name(s).
			'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'kybully' ), // %1$s = plugin name(s).
			'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'kybully' ), // %1$s = plugin name(s).
			'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'kybully' ), // %1$s = plugin name(s).
			'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'kybully' ), // %1$s = plugin name(s).
			'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'kybully' ), // %1$s = plugin name(s).
			'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'kybully' ), // %1$s = plugin name(s).
			'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'kybully' ), // %1$s = plugin name(s).
			'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'kybully' ),
			'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins', 'kybully' ),
			'return'                          => __( 'Return to Required Plugins Installer', 'kybully' ),
			'plugin_activated'                => __( 'Plugin activated successfully.', 'kybully' ),
			'complete'                        => __( 'All plugins installed and activated successfully. %s', 'kybully' ), // %s = dashboard link.
			'nag_type'                        => 'updated', // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
		)
	);

	tgmpa( $plugins, $config );

}
